@@ -7,9 +7,9 @@ from _plotly_utils.utils import PlotlyJSONEncoder
 from .jupyter import register_jupyter
 from .string import task_string_to_context
 
-__author__ = """Brent Baumgartner"""
-__email__ = "brent@twinthread.com"
-__version__ = "0.4.0"
+__author__ = """Brad Johnson"""
+__email__ = "brad.johnson@twinthread.com"
+__version__ = "1.2.0"
 
 import re
 import json
@@ -338,14 +338,14 @@ class TwinThreadClient:
 
     def __save_remote_file(self, file_type, name, contents):
         blob_name = re.sub(r"\W+", "", name).lower()
+        filename = f"{blob_name}{file_suffix}"
         file_suffix = (
             ".json" if file_type == "json" else ".png" if file_type == "png" else ""
         )
         blob_name = f"{self.__context['assetModelId']}_{self.__context['taskId']}_{blob_name}_org_i0{file_suffix}"
 
         self.__auth_check()
-
-        filename = f"{type}_{name}"
+        
         self.__write_file_contents(file_type, filename, contents)
 
         from requests_toolbelt import MultipartEncoder
